local gears = require("gears")
local awful = require("awful")
local wibox = require("wibox")
local switcherpopup = require("awesome-switcherpopup")
local launcherpopup = require("awesome-launcherpopup")
local longpress = require("awesome-longpress")

local navbar = {
  iconSize = 96,
  iconPath = gears.filesystem.get_configuration_dir() .. "/awesome-navbar/",
  launcher = "xfce4-appfinder"
}

function navbar.new(s)
  local landscape = s.geometry.width > s.geometry.height
  local portrait = not landscape
  local tasklist = switcherpopup.new(s)
  local launcher = launcherpopup.new(s)
  local switcher_button = wibox.container.place(awful.widget.button({image = navbar.iconPath .. "/switcher.svg"}), "center", "center")
  switcher_button:buttons(gears.table.join(
    switcher_button:buttons(),
    awful.button({}, 1, nil, function()
      launcher:hide()
      tasklist:toggle()
    end)
  ))
  local kb_button = wibox.container.place(awful.widget.button({image = navbar.iconPath .. "/keyboard.svg"}), "center", "center")
  kb_button:buttons(gears.table.join(
    kb_button:buttons(),
    awful.button({}, 1, nil, function()
      s.keyboard.visible = not s.keyboard.visible
    end)
  ))
  local launcher_button = wibox.container.place(awful.widget.button({image = navbar.iconPath .. "/launcher.svg"}), "center", "center")
  longpress.add(launcher_button,function()
    tasklist:hide()
    launcher:toggle()
   end,
   function()
     awful.spawn(navbar.launcher)
   end)

  local rnavbar = awful.wibar({
    ontop = true,
    screen = s
  })
  function rnavbar.reflow()
    rnavbar.position = landscape and "left" or "bottom"
    rnavbar.height = (portrait and navbar.iconSize) or nil
    rnavbar.width = (landscape and navbar.iconSize) or nil
    rnavbar:setup({
      layout = landscape and wibox.layout.ratio.vertical or wibox.layout.ratio.horizontal, launcher_button, switcher_button, kb_button
    })
  end
  rnavbar.reflow()

  s.keyboard = awful.wibar({
    height = s.geometry.height * 0.25,
    opacity = 0.75,
    position = "bottom",
    visible = false,
    ontop = true,
    screen = s
  })

  vkbd.spacing = 1
  s.keyboard:setup ({
    layout = wibox.layout.ratio.horizontal,
    vkbd
  })
  return rnavbar
end
return navbar
